@@ -18,6 +18,9 @@ class AliasBlockView(BaseBlock):
     def has_view_permission(self):
         return api.user.has_permission('View', obj=self.referenced_obj)
 
+    def can_modify(self):
+        return api.user.has_permission('Modify portal content', obj=self.referenced_obj)
+
     def referece_is_page(self):
         return ISimplelayout.providedBy(self.referenced_obj)
 
