@@ -2,10 +2,11 @@ from ftw.builder.testing import BUILDER_LAYER
 from ftw.builder.testing import functional_session_factory
 from ftw.builder.testing import set_builder_session_factory
 from ftw.simplelayout.tests import sample_types
+from ftw.simplelayout.utils import IS_PLONE_5
 from ftw.testing.layer import ComponentRegistryLayer
+from path import Path
 from persistent.list import PersistentList
 from persistent.mapping import PersistentMapping
-from pkg_resources import get_distribution
 from plone.app.testing import applyProfile
 from plone.app.testing import FunctionalTesting
 from plone.app.testing import IntegrationTesting
@@ -14,13 +15,10 @@ from plone.app.testing import PloneSandboxLayer
 from plone.app.testing import setRoles, TEST_USER_ID, TEST_USER_NAME, login
 from plone.testing import z2
 from plone.testing import zca
-from unittest2 import TestCase
+from unittest import TestCase
 from zope.configuration import xmlconfig
-import ftw.simplelayout.tests.builders  # noqa
 import ftw.referencewidget.tests.widgets  # noqa
-
-
-IS_PLONE_5 = get_distribution('Plone').version >= '5'
+import ftw.simplelayout.tests.builders  # noqa
 
 
 class SimplelayoutZCMLLayer(ComponentRegistryLayer):
@@ -58,7 +56,6 @@ class FtwSimplelayoutLayer(PloneSandboxLayer):
 
     def setUpPloneSite(self, portal):
         applyProfile(portal, 'ftw.simplelayout:lib')
-        applyProfile(portal, 'plone.restapi:default')
 
         setRoles(portal, TEST_USER_ID, ['Manager', 'Site Administrator'])
         login(portal, TEST_USER_NAME)
@@ -67,10 +64,13 @@ class FtwSimplelayoutLayer(PloneSandboxLayer):
 class FtwSimplelayoutContentLayer(FtwSimplelayoutLayer):
     def setUpPloneSite(self, portal):
 
-        if not IS_PLONE_5:
-            applyProfile(portal, 'ftw.simplelayout.contenttypes:default')
-            applyProfile(portal, 'ftw.simplelayout.mapblock:default')
-            applyProfile(portal, 'ftw.simplelayout.aliasblock:default')
+        applyProfile(portal, 'ftw.simplelayout.contenttypes:default')
+        applyProfile(portal, 'ftw.simplelayout.mapblock:default')
+        applyProfile(portal, 'ftw.simplelayout.aliasblock:default')
+        applyProfile(portal, 'ftw.file:default')
+
+        if IS_PLONE_5:
+            applyProfile(portal, 'plone.app.contenttypes:default')
 
         setRoles(portal, TEST_USER_ID, ['Manager', 'Site Administrator'])
         login(portal, TEST_USER_NAME)
@@ -81,7 +81,7 @@ class SimplelayoutTestCase(TestCase):
     def assert_recursive_persistence(self, structure):
 
         def is_persistent(item):
-            if not isinstance(item, basestring) and not isinstance(item, int):
+            if not isinstance(item, basestring) and not isinstance(item, int):  # noqa
                 assert isinstance(item, PersistentMapping) or \
                     isinstance(item, PersistentList), \
                     '{0} needs to be persistent'.format(str(item))
@@ -97,7 +97,7 @@ class SimplelayoutTestCase(TestCase):
 
     def assert_unwrapped_persistence(self, structure):
         def is_unwrapped(item):
-            if not isinstance(item, basestring) and not isinstance(item, int):
+            if not isinstance(item, basestring) and not isinstance(item, int):  # noqa
                 assert isinstance(item, dict) or \
                     isinstance(item, list), \
                     '{0} needs to be unwrapped'.format(str(item))
@@ -117,6 +117,9 @@ class SimplelayoutTestCase(TestCase):
     def setup_block_views(self):
         sample_types.setup_views()
 
+    def asset(self, name):
+        return Path(__file__).joinpath('..', 'tests', 'assets', name).abspath()
+
 
 FTW_SIMPLELAYOUT_FIXTURE = FtwSimplelayoutLayer()
 FTW_SIMPLELAYOUT_INTEGRATION_TESTING = IntegrationTesting(
