@@ -1,13 +1,10 @@
 from ftw.builder import Builder
 from ftw.builder import create
 from ftw.simplelayout.testing import FTW_SIMPLELAYOUT_CONTENT_TESTING
-from ftw.simplelayout.testing import IS_PLONE_5
 from ftw.testbrowser import browsing
-from unittest import skipUnless
 from unittest import TestCase
 
 
-@skipUnless(not IS_PLONE_5, 'requires plone < 5')
 class TestDefaultPageForm(TestCase):
 
     layer = FTW_SIMPLELAYOUT_CONTENT_TESTING
